@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 from __future__ import absolute_import
@@ -9,9 +8,10 @@ from .atd95 import ATD95_Specification, XYZ_to_ATD95
 from .ciecam02 import (CIECAM02_InductionFactors, CIECAM02_VIEWING_CONDITIONS,
                        CIECAM02_Specification, XYZ_to_CIECAM02,
                        CIECAM02_to_XYZ)
-from .llab import (  # noqa
-    LLAB_InductionFactors, LLAB_VIEWING_CONDITIONS, LLAB_Specification,
-    XYZ_to_LLAB)
+from .cam16 import (CAM16_InductionFactors, CAM16_VIEWING_CONDITIONS,
+                    CAM16_Specification, XYZ_to_CAM16, CAM16_to_XYZ)
+from .llab import (LLAB_InductionFactors, LLAB_VIEWING_CONDITIONS,
+                   LLAB_Specification, XYZ_to_LLAB)
 from .nayatani95 import Nayatani95_Specification, XYZ_to_Nayatani95
 from .rlab import (RLAB_VIEWING_CONDITIONS, RLAB_D_FACTOR, RLAB_Specification,
                    XYZ_to_RLAB)
@@ -25,7 +25,14 @@ __all__ += [
     'CIECAM02_InductionFactors', 'CIECAM02_VIEWING_CONDITIONS',
     'CIECAM02_Specification', 'XYZ_to_CIECAM02', 'CIECAM02_to_XYZ'
 ]
-__all__ += ['LLAB_VIEWING_CONDITIONS', 'LLAB_Specification', 'XYZ_to_LLAB']
+__all__ += [
+    'CAM16_InductionFactors', 'CAM16_VIEWING_CONDITIONS',
+    'CAM16_Specification', 'XYZ_to_CAM16', 'CAM16_to_XYZ'
+]
+__all__ += [
+    'LLAB_InductionFactors', 'LLAB_VIEWING_CONDITIONS', 'LLAB_Specification',
+    'XYZ_to_LLAB'
+]
 __all__ += ['Nayatani95_Specification', 'XYZ_to_Nayatani95']
 __all__ += [
     'RLAB_VIEWING_CONDITIONS', 'RLAB_D_FACTOR', 'RLAB_Specification',
