@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 Light Sources Chromaticity Coordinates
@@ -38,6 +37,16 @@ See Also
 `Light Sources Jupyter Notebook
 <http://nbviewer.jupyter.org/github/colour-science/colour-notebooks/\
 blob/master/notebooks/colorimetry/light_sources.ipynb>`_
+
+References
+----------
+-   :cite:`Houston2015a` : Houston, J. (2015). Private Discussion with
+    Mansencal, T.
+-   :cite:`Ohno2008a` : Ohno, Y., & Davis, W. (2008). NIST CQS simulation 7.4.
+    Retrieved from https://drive.google.com/file/d/\
+1PsuU6QjUJjCX6tQyCud6ul2Tbs8rYWW9/view?usp=sharing
+-   :cite:`Pointer1980a` : Pointer, M. R. (1980). Pointer's Gamut Data.
+    Retrieved from http://www.cis.rit.edu/research/mcsl2/online/PointerData.xls
 """
 
 from __future__ import division, unicode_literals
@@ -47,7 +56,7 @@ import numpy as np
 from colour.utilities import CaseInsensitiveMapping
 
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2018 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
@@ -97,9 +106,7 @@ spreadsheet that doesn't mention the data source thus the light source names
 cannot be accurately verified.
 
 References
-----------
-.. [1]  Pointer, M. R. (1980). Pointer's Gamut Data. Retrieved from
-        http://www.cis.rit.edu/research/mcsl2/online/PointerData.xls
+-   :cite:`Pointer1980a`
 
 LIGHT_SOURCES_RIT_CIE_1931_2_DEGREE_STANDARD_OBSERVER : CaseInsensitiveMapping
     **{'Natural', 'Philips TL-84', 'T8 Luxline Plus White', 'SA', 'SC',
@@ -163,8 +170,7 @@ Traditional light sources chromaticity coordinates from *NIST*
 
 References
 ----------
-.. [2]  Ohno, Y., & Davis, W. (2008). NIST CQS simulation 7.4. Retrieved from
-        http://cie2.nist.gov/TC1-69/NIST CQS simulation 7.4.xls
+-   :cite:`Ohno2008a`
 
 LIGHT_SOURCES_NIST_TRADITIONAL_CIE_1931_2_DEGREE_STANDARD_OBSERVER :
     CaseInsensitiveMapping
@@ -433,7 +439,7 @@ Projectors and Xenon Arc Lamps.
 
 References
 ----------
-.. [3]  Houston, J. (2015). Private Discussion with Mansencal, T.
+-   :cite:`Houston2015a`
 
 LIGHT_SOURCES_PROJECTORS_CIE_1931_2_DEGREE_STANDARD_OBSERVER :
     CaseInsensitiveMapping
@@ -460,7 +466,7 @@ LIGHT_SOURCES = CaseInsensitiveMapping({
         CaseInsensitiveMapping(
             LIGHT_SOURCES_RIT_CIE_1964_10_DEGREE_STANDARD_OBSERVER)
 })
-"""
+LIGHT_SOURCES.__doc__ = """
 Aggregated light sources chromaticity coordinates.
 
 LIGHT_SOURCES : CaseInsensitiveMapping
