@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 from __future__ import absolute_import
@@ -6,10 +5,14 @@ from __future__ import absolute_import
 from .cie import CIE_E, CIE_K, K_M, KP_M
 from .codata import (AVOGADRO_CONSTANT, BOLTZMANN_CONSTANT, LIGHT_SPEED,
                      PLANCK_CONSTANT)
-from .common import FLOATING_POINT_NUMBER_PATTERN, INTEGER_THRESHOLD, EPSILON
+from .common import (FLOATING_POINT_NUMBER_PATTERN, INTEGER_THRESHOLD, EPSILON,
+                     DEFAULT_FLOAT_DTYPE)
 
 __all__ = ['CIE_E', 'CIE_K', 'K_M', 'KP_M']
 __all__ += [
     'AVOGADRO_CONSTANT', 'BOLTZMANN_CONSTANT', 'LIGHT_SPEED', 'PLANCK_CONSTANT'
 ]
-__all__ += ['FLOATING_POINT_NUMBER_PATTERN', 'INTEGER_THRESHOLD', 'EPSILON']
+__all__ += [
+    'FLOATING_POINT_NUMBER_PATTERN', 'INTEGER_THRESHOLD', 'EPSILON',
+    'DEFAULT_FLOAT_DTYPE'
+]
