@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 Common Constants
@@ -11,14 +10,19 @@ from __future__ import division, unicode_literals
 
 import numpy as np
 
+from colour.utilities.documentation import DocstringFloat
+
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2018 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['FLOATING_POINT_NUMBER_PATTERN', 'INTEGER_THRESHOLD', 'EPSILON']
+__all__ = [
+    'FLOATING_POINT_NUMBER_PATTERN', 'INTEGER_THRESHOLD', 'EPSILON',
+    'DEFAULT_FLOAT_DTYPE'
+]
 
 FLOATING_POINT_NUMBER_PATTERN = '[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?'
 """
@@ -27,8 +31,8 @@ Floating point number regex matching pattern.
 FLOATING_POINT_NUMBER_PATTERN : unicode
 """
 
-INTEGER_THRESHOLD = 1e-3
-"""
+INTEGER_THRESHOLD = DocstringFloat(1e-3)
+INTEGER_THRESHOLD.__doc__ = """
 Integer threshold value.
 
 INTEGER_THRESHOLD : numeric
@@ -41,3 +45,10 @@ computations.
 
 EPSILON : numeric
 """
+
+DEFAULT_FLOAT_DTYPE = np.float_
+"""
+Default floating point number dtype.
+
+DEFAULT_FLOAT_DTYPE : type
+"""
