@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 Breneman Corresponding Chromaticities Dataset
@@ -14,10 +13,10 @@ blob/master/notebooks/corresponding/prediction.ipynb>`_
 
 References
 ----------
-.. [1]  Breneman, E. J. (1987). Corresponding chromaticities for different
-        states of adaptation to complex visual fields. JOSA A, 4(6). Retrieved
-        from http://www.opticsinfobase.org/josaa/\
-fulltext.cfm?uri=josaa-4-6-1115&id=2783
+-   :cite:`Breneman1987b` : Breneman, E. J. (1987). Corresponding
+    chromaticities for different states of adaptation to complex visual fields.
+    Journal of the Optical Society of America A, 4(6), 1115.
+    doi:10.1364/JOSAA.4.001115
 """
 
 from __future__ import division, unicode_literals
@@ -26,8 +25,10 @@ import numpy as np
 
 from collections import namedtuple
 
+from colour.utilities.documentation import DocstringDict
+
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2018 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
@@ -77,7 +78,9 @@ class BrenemanExperimentResult(
                 d_uvp_i=None,
                 d_uvp_g=None):
         """
-        Returns a new instance of the :class:`BrenemanExperimentResult` class.
+        Returns a new instance of the
+        :class:`colour.corresponding.dataset.corresponding_chromaticities.\
+BrenemanExperimentResult` class.
         """
 
         return super(BrenemanExperimentResult, cls).__new__(
@@ -118,7 +121,9 @@ class PrimariesChromaticityCoordinates(
                 d_uvp_i=None,
                 d_uvp_g=None):
         """
-        Returns a new instance of the :class:`BrenemanExperimentResult` class.
+        Returns a new instance of the
+        :class:`colour.corresponding.dataset.corresponding_chromaticities.\
+PrimariesChromaticityCoordinates` class.
         """
 
         return super(PrimariesChromaticityCoordinates, cls).__new__(
@@ -788,7 +793,7 @@ Notes
 """
 
 # yapf: disable
-BRENEMAN_EXPERIMENTS_PRIMARIES_CHROMATICITIES = {
+BRENEMAN_EXPERIMENTS_PRIMARIES_CHROMATICITIES = DocstringDict({
     1: PrimariesChromaticityCoordinates(
         1, ('A', 'D65'), 1500,
         (0.671, 0.519), (-0.586, 0.627), (0.253, 0.016)),
@@ -815,15 +820,19 @@ BRENEMAN_EXPERIMENTS_PRIMARIES_CHROMATICITIES = {
         (0.680, 0.529), (0.018, 0.576), (0.307, 0.080)),
     12: PrimariesChromaticityCoordinates(
         12, ('D55', 'green'), 75,
-        (0.661, 0.505), (0.039, 0.598), (0.345, 0.127))}
+        (0.661, 0.505), (0.039, 0.598), (0.345, 0.127))})
 # yapf: enable
-"""
+BRENEMAN_EXPERIMENTS_PRIMARIES_CHROMATICITIES.__doc__ = """
 *Breneman (1987)* experiments primaries chromaticities.
 
+References
+----------
+-   :cite:`Breneman1987b`
+
 BRENEMAN_EXPERIMENTS_PRIMARIES_CHROMATICITIES : dict
 """
 
-BRENEMAN_EXPERIMENTS = {
+BRENEMAN_EXPERIMENTS = DocstringDict({
     1: BRENEMAN_EXPERIMENT_1_RESULTS,
     2: BRENEMAN_EXPERIMENT_2_RESULTS,
     3: BRENEMAN_EXPERIMENT_3_RESULTS,
@@ -836,9 +845,13 @@ BRENEMAN_EXPERIMENTS = {
     10: BRENEMAN_EXPERIMENT_10_RESULTS,
     11: BRENEMAN_EXPERIMENT_11_RESULTS,
     12: BRENEMAN_EXPERIMENT_12_RESULTS
-}
-"""
+})
+BRENEMAN_EXPERIMENTS.__doc__ = """
 *Breneman (1987)* experiments.
 
+References
+----------
+-   :cite:`Breneman1987b`
+
 BRENEMAN_EXPERIMENTS : dict
 """
