@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 Showcases illuminants dataset.
@@ -7,7 +6,7 @@ Showcases illuminants dataset.
 from pprint import pprint
 
 import colour
-from colour.utilities.verbose import message_box
+from colour.utilities import message_box
 
 message_box('Illuminants Dataset')
 
