@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 Showcases input / output *CSV* tabular data related examples.
@@ -9,7 +8,7 @@ from pprint import pprint
 
 import colour
 from colour.io.common import format_spectral_data
-from colour.utilities.verbose import message_box
+from colour.utilities import message_box
 
 RESOURCES_DIRECTORY = os.path.join(os.path.dirname(__file__), 'resources')
 
