@@ -1,19 +1,23 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 Showcases reflectance recovery computations using *Smits (1999)* method.
 """
 
+import numpy as np
+
 import colour
-from colour.utilities.verbose import message_box
+from colour.recovery.smits1999 import XYZ_to_RGB_Smits1999
+from colour.utilities import message_box
 
 message_box('"Smits (1999)" - Reflectance Recovery Computations')
 
-RGB = (0.35505307, 0.47995567, 0.61088035)
+XYZ = np.array([1.14176346, 1.00000000, 0.49815206])
+RGB = XYZ_to_RGB_Smits1999(XYZ)
 message_box(('Recovering reflectance using "Smits (1999)" method from '
              'given "RGB" colourspace array:\n'
              '\n\tRGB: {0}'.format(RGB)))
-print(colour.RGB_to_spectral_Smits1999(RGB))
+print(colour.XYZ_to_spectral(XYZ, method='Smits 1999'))
+print(colour.recovery.RGB_to_spectral_Smits1999(RGB))
 
 print('\n')
 
