@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
 CIE Chromaticity Diagrams Plotting
@@ -6,12 +5,12 @@ CIE Chromaticity Diagrams Plotting
 
 Defines the *CIE* chromaticity diagrams plotting objects:
 
--   :func:`CIE_1931_chromaticity_diagram_plot`
--   :func:`CIE_1960_UCS_chromaticity_diagram_plot`
--   :func:`CIE_1976_UCS_chromaticity_diagram_plot`
--   :func:`spds_CIE_1931_chromaticity_diagram_plot`
--   :func:`spds_CIE_1960_UCS_chromaticity_diagram_plot`
--   :func:`spds_CIE_1976_UCS_chromaticity_diagram_plot`
+-   :func:`colour.plotting.chromaticity_diagram_plot_CIE1931`
+-   :func:`colour.plotting.chromaticity_diagram_plot_CIE1960UCS`
+-   :func:`colour.plotting.chromaticity_diagram_plot_CIE1976UCS`
+-   :func:`colour.plotting.spds_chromaticity_diagram_plot_CIE1931`
+-   :func:`colour.plotting.spds_chromaticity_diagram_plot_CIE1960UCS`
+-   :func:`colour.plotting.spds_chromaticity_diagram_plot_CIE1976UCS`
 """
 
 from __future__ import division
@@ -24,61 +23,61 @@ import matplotlib.image
 import matplotlib.pyplot
 import numpy as np
 import pylab
+from scipy.ndimage.filters import convolve
 from scipy.spatial import Delaunay
 
 from colour.algebra import normalise_vector
 from colour.colorimetry import spectral_to_XYZ
+from colour.constants import DEFAULT_FLOAT_DTYPE
 from colour.models import (Luv_to_uv, Luv_uv_to_xy, UCS_to_uv, UCS_uv_to_xy,
                            XYZ_to_Luv, XYZ_to_UCS, XYZ_to_sRGB, XYZ_to_xy,
                            xy_to_XYZ)
 from colour.plotting import (DEFAULT_FIGURE_WIDTH, DEFAULT_PLOTTING_ILLUMINANT,
-                             PLOTTING_RESOURCES_DIRECTORY, canvas, decorate,
-                             boundaries, display, get_cmfs)
-from colour.utilities import normalise_maximum, tsplit, tstack
+                             PLOTTING_RESOURCES_DIRECTORY, canvas, get_cmfs,
+                             render)
+from colour.utilities import normalise_maximum, tstack
 
 __author__ = 'Colour Developers'
-__copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
+__copyright__ = 'Copyright (C) 2013-2018 - Colour Developers'
 __license__ = 'New BSD License - http://opensource.org/licenses/BSD-3-Clause'
 __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
 __all__ = [
-    'CIE_1931_chromaticity_diagram_colours_plot',
-    'CIE_1931_chromaticity_diagram_plot',
-    'CIE_1960_UCS_chromaticity_diagram_colours_plot',
-    'CIE_1960_UCS_chromaticity_diagram_plot',
-    'CIE_1976_UCS_chromaticity_diagram_colours_plot',
-    'CIE_1976_UCS_chromaticity_diagram_plot',
-    'spds_CIE_1931_chromaticity_diagram_plot',
-    'spds_CIE_1960_UCS_chromaticity_diagram_plot',
-    'spds_CIE_1976_UCS_chromaticity_diagram_plot'
+    'chromaticity_diagram_colours_CIE1931',
+    'chromaticity_diagram_plot_CIE1931',
+    'chromaticity_diagram_colours_CIE1960UCS',
+    'chromaticity_diagram_plot_CIE1960UCS',
+    'chromaticity_diagram_colours_CIE1976UCS',
+    'chromaticity_diagram_plot_CIE1976UCS',
+    'spds_chromaticity_diagram_plot_CIE1931',
+    'spds_chromaticity_diagram_plot_CIE1960UCS',
+    'spds_chromaticity_diagram_plot_CIE1976UCS'
 ]
 
 
-def CIE_1931_chromaticity_diagram_colours_plot(
-        surface=1,
+def chromaticity_diagram_colours_CIE1931(
         samples=4096,
         cmfs='CIE 1931 2 Degree Standard Observer',
-        **kwargs):
+        antialiasing=True):
     """
     Plots the *CIE 1931 Chromaticity Diagram* colours.
 
     Parameters
     ----------
-    surface : numeric, optional
-        Generated markers surface.
     samples : numeric, optional
         Samples count on one axis.
     cmfs : unicode, optional
         Standard observer colour matching functions used for diagram bounds.
+    antialiasing : bool, optional
+        Whether to apply anti-aliasing to the image.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
-        Please refer to the documentation of the previously listed definitions.
+        {:func:`colour.plotting.render`},
+        Please refer to the documentation of the previously listed definition.
 
     Returns
     -------
@@ -87,52 +86,41 @@ def CIE_1931_chromaticity_diagram_colours_plot(
 
     Examples
     --------
-    >>> CIE_1931_chromaticity_diagram_colours_plot()  # doctest: +SKIP
+    >>> chromaticity_diagram_colours_CIE1931()  # doctest: +SKIP
     """
 
-    settings = {'figure_size': (64, 64)}
-    settings.update(kwargs)
-
-    canvas(**settings)
-
     cmfs = get_cmfs(cmfs)
 
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
     triangulation = Delaunay(
-        XYZ_to_xy(cmfs.values, illuminant), qhull_options='QJ')
+        XYZ_to_xy(cmfs.values, illuminant), qhull_options='Qu QJ')
     xx, yy = np.meshgrid(
-        np.linspace(0, 1, samples), np.linspace(0, 1, samples))
+        np.linspace(0, 1, samples), np.linspace(1, 0, samples))
     xy = tstack((xx, yy))
-    xy = xy[triangulation.find_simplex(xy) > 0]
+    mask = (triangulation.find_simplex(xy) < 0).astype(DEFAULT_FLOAT_DTYPE)
+    if antialiasing:
+        kernel = np.array([
+            [0, 1, 0],
+            [1, 2, 1],
+            [0, 1, 0],
+        ]).astype(DEFAULT_FLOAT_DTYPE)
+        kernel /= np.sum(kernel)
+        mask = convolve(mask, kernel)
+
+    mask = 1 - mask[:, :, np.newaxis]
 
     XYZ = xy_to_XYZ(xy)
 
     RGB = normalise_maximum(XYZ_to_sRGB(XYZ, illuminant), axis=-1)
 
-    x_dot, y_dot = tsplit(xy)
-
-    pylab.scatter(x_dot, y_dot, color=RGB, s=surface)
-
-    settings.update({
-        'x_ticker': False,
-        'y_ticker': False,
-        'bounding_box': (0, 1, 0, 1)
-    })
-    settings.update(kwargs)
-
-    ax = matplotlib.pyplot.gca()
-    matplotlib.pyplot.setp(ax, frame_on=False)
-
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return np.dstack([RGB, mask])
 
 
-def CIE_1931_chromaticity_diagram_plot(
+def chromaticity_diagram_plot_CIE1931(
         cmfs='CIE 1931 2 Degree Standard Observer',
         show_diagram_colours=True,
+        use_cached_diagram_colours=True,
         **kwargs):
     """
     Plots the *CIE 1931 Chromaticity Diagram*.
@@ -143,12 +131,15 @@ def CIE_1931_chromaticity_diagram_plot(
         Standard observer colour matching functions used for diagram bounds.
     show_diagram_colours : bool, optional
         Whether to display the chromaticity diagram background colours.
+    use_cached_diagram_colours : bool, optional
+        Whether to used the cached chromaticity diagram background colours
+        image.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
+        {:func:`colour.plotting.diagrams.chromaticity_diagram_colours_CIE1931`,
+        :func:`colour.plotting.render`},
         Please refer to the documentation of the previously listed definitions.
 
     Returns
@@ -158,7 +149,7 @@ def CIE_1931_chromaticity_diagram_plot(
 
     Examples
     --------
-    >>> CIE_1931_chromaticity_diagram_plot()  # doctest: +SKIP
+    >>> chromaticity_diagram_plot_CIE1931()  # doctest: +SKIP
     """
 
     settings = {'figure_size': (DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_WIDTH)}
@@ -171,11 +162,18 @@ def CIE_1931_chromaticity_diagram_plot(
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
     if show_diagram_colours:
-        image = matplotlib.image.imread(
-            os.path.join(PLOTTING_RESOURCES_DIRECTORY,
-                         'CIE_1931_Chromaticity_Diagram_{0}.png'.format(
-                             cmfs.name.replace(' ', '_'))))
-        pylab.imshow(image, interpolation=None, extent=(0, 1, 0, 1))
+        if use_cached_diagram_colours:
+            image = matplotlib.image.imread(
+                os.path.join(PLOTTING_RESOURCES_DIRECTORY,
+                             'CIE_1931_Chromaticity_Diagram_{0}.png'.format(
+                                 cmfs.name.replace(' ', '_'))))
+        else:
+            image = chromaticity_diagram_colours_CIE1931(
+                samples=kwargs.get('samples', 256),
+                cmfs=cmfs.name,
+                antialiasing=kwargs.get('antialiasing', True))
+
+        pylab.imshow(image, interpolation='bilinear', extent=(0, 1, 0, 1))
 
     labels = (390, 460, 470, 480, 490, 500, 510, 520, 540, 560, 580, 600, 620,
               700)
@@ -187,15 +185,15 @@ def CIE_1931_chromaticity_diagram_plot(
 
     wavelengths_chromaticity_coordinates = dict(tuple(zip(wavelengths, xy)))
 
-    pylab.plot(xy[..., 0], xy[..., 1], color='black', linewidth=2)
+    pylab.plot(xy[..., 0], xy[..., 1], color='black', linewidth=1)
     pylab.plot(
         (xy[-1][0], xy[0][0]), (xy[-1][1], xy[0][1]),
         color='black',
-        linewidth=2)
+        linewidth=1)
 
     for label in labels:
         x, y = wavelengths_chromaticity_coordinates[label]
-        pylab.plot(x, y, 'o', color='black', linewidth=2)
+        pylab.plot(x, y, 'o', color='black', linewidth=1)
 
         index = bisect.bisect(wavelengths, label)
         left = wavelengths[index - 1] if index >= 0 else wavelengths[index]
@@ -236,43 +234,42 @@ def CIE_1931_chromaticity_diagram_plot(
     pylab.yticks(ticks)
 
     settings.update({
-        'title': 'CIE 1931 Chromaticity Diagram - {0}'.format(cmfs.title),
-        'x_label': 'CIE x',
-        'y_label': 'CIE y',
-        'grid': True,
+        'title':
+            'CIE 1931 Chromaticity Diagram - {0}'.format(cmfs.strict_name),
+        'x_label':
+            'CIE x',
+        'y_label':
+            'CIE y',
+        'grid':
+            True,
         'bounding_box': (0, 1, 0, 1)
     })
     settings.update(kwargs)
 
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return render(**settings)
 
 
-def CIE_1960_UCS_chromaticity_diagram_colours_plot(
-        surface=1,
+def chromaticity_diagram_colours_CIE1960UCS(
         samples=4096,
         cmfs='CIE 1931 2 Degree Standard Observer',
-        **kwargs):
+        antialiasing=True):
     """
     Plots the *CIE 1960 UCS Chromaticity Diagram* colours.
 
     Parameters
     ----------
-    surface : numeric, optional
-        Generated markers surface.
     samples : numeric, optional
         Samples count on one axis.
     cmfs : unicode, optional
         Standard observer colour matching functions used for diagram bounds.
+    antialiasing : bool, optional
+        Whether to apply anti-aliasing to the image.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
-        Please refer to the documentation of the previously listed definitions.
+        {:func:`colour.plotting.render`},
+        Please refer to the documentation of the previously listed definition.
 
     Returns
     -------
@@ -281,52 +278,41 @@ def CIE_1960_UCS_chromaticity_diagram_colours_plot(
 
     Examples
     --------
-    >>> CIE_1960_UCS_chromaticity_diagram_colours_plot()  # doctest: +SKIP
+    >>> chromaticity_diagram_colours_CIE1960UCS()  # doctest: +SKIP
     """
 
-    settings = {'figure_size': (64, 64)}
-    settings.update(kwargs)
-
-    canvas(**settings)
-
     cmfs = get_cmfs(cmfs)
 
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
     triangulation = Delaunay(
-        UCS_to_uv(XYZ_to_UCS(cmfs.values)), qhull_options='QJ')
+        UCS_to_uv(XYZ_to_UCS(cmfs.values)), qhull_options='Qu QJ')
     xx, yy = np.meshgrid(
-        np.linspace(0, 1, samples), np.linspace(0, 1, samples))
+        np.linspace(0, 1, samples), np.linspace(1, 0, samples))
     xy = tstack((xx, yy))
-    xy = xy[triangulation.find_simplex(xy) > 0]
+    mask = (triangulation.find_simplex(xy) < 0).astype(DEFAULT_FLOAT_DTYPE)
+    if antialiasing:
+        kernel = np.array([
+            [0, 1, 0],
+            [1, 2, 1],
+            [0, 1, 0],
+        ]).astype(DEFAULT_FLOAT_DTYPE)
+        kernel /= np.sum(kernel)
+        mask = convolve(mask, kernel)
+
+    mask = 1 - mask[:, :, np.newaxis]
 
     XYZ = xy_to_XYZ(UCS_uv_to_xy(xy))
 
     RGB = normalise_maximum(XYZ_to_sRGB(XYZ, illuminant), axis=-1)
 
-    x_dot, y_dot = tsplit(xy)
-
-    pylab.scatter(x_dot, y_dot, color=RGB, s=surface)
-
-    settings.update({
-        'x_ticker': False,
-        'y_ticker': False,
-        'bounding_box': (0, 1, 0, 1)
-    })
-    settings.update(kwargs)
-
-    ax = matplotlib.pyplot.gca()
-    matplotlib.pyplot.setp(ax, frame_on=False)
-
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return np.dstack([RGB, mask])
 
 
-def CIE_1960_UCS_chromaticity_diagram_plot(
+def chromaticity_diagram_plot_CIE1960UCS(
         cmfs='CIE 1931 2 Degree Standard Observer',
         show_diagram_colours=True,
+        use_cached_diagram_colours=True,
         **kwargs):
     """
     Plots the *CIE 1960 UCS Chromaticity Diagram*.
@@ -337,12 +323,15 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
         Standard observer colour matching functions used for diagram bounds.
     show_diagram_colours : bool, optional
         Whether to display the chromaticity diagram background colours.
+    use_cached_diagram_colours : bool, optional
+        Whether to used the cached chromaticity diagram background colours
+        image.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
+        {:func:`colour.plotting.diagrams.\
+chromaticity_diagram_colours_CIE1960UCS`, :func:`colour.plotting.render`},
         Please refer to the documentation of the previously listed definitions.
 
     Returns
@@ -352,7 +341,7 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
 
     Examples
     --------
-    >>> CIE_1960_UCS_chromaticity_diagram_plot()  # doctest: +SKIP
+    >>> chromaticity_diagram_plot_CIE1960UCS()  # doctest: +SKIP
     """
 
     settings = {'figure_size': (DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_WIDTH)}
@@ -363,11 +352,18 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
     cmfs = get_cmfs(cmfs)
 
     if show_diagram_colours:
-        image = matplotlib.image.imread(
-            os.path.join(PLOTTING_RESOURCES_DIRECTORY,
-                         'CIE_1960_UCS_Chromaticity_Diagram_{0}.png'.format(
-                             cmfs.name.replace(' ', '_'))))
-        pylab.imshow(image, interpolation=None, extent=(0, 1, 0, 1))
+        if use_cached_diagram_colours:
+            image = matplotlib.image.imread(
+                os.path.join(PLOTTING_RESOURCES_DIRECTORY,
+                             'CIE_1960_UCS_Chromaticity_Diagram_{0}.png'.
+                             format(cmfs.name.replace(' ', '_'))))
+        else:
+            image = chromaticity_diagram_colours_CIE1960UCS(
+                samples=kwargs.get('samples', 256),
+                cmfs=cmfs.name,
+                antialiasing=kwargs.get('antialiasing', True))
+
+        pylab.imshow(image, interpolation='bilinear', extent=(0, 1, 0, 1))
 
     labels = (420, 430, 440, 450, 460, 470, 480, 490, 500, 510, 520, 530, 540,
               550, 560, 570, 580, 590, 600, 610, 620, 630, 640, 680)
@@ -379,15 +375,15 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
 
     wavelengths_chromaticity_coordinates = dict(tuple(zip(wavelengths, uv)))
 
-    pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=2)
+    pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=1)
     pylab.plot(
         (uv[-1][0], uv[0][0]), (uv[-1][1], uv[0][1]),
         color='black',
-        linewidth=2)
+        linewidth=1)
 
     for label in labels:
         u, v = wavelengths_chromaticity_coordinates[label]
-        pylab.plot(u, v, 'o', color='black', linewidth=2)
+        pylab.plot(u, v, 'o', color='black', linewidth=1)
 
         index = bisect.bisect(wavelengths, label)
         left = wavelengths[index - 1] if index >= 0 else wavelengths[index]
@@ -428,43 +424,42 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
     pylab.yticks(ticks)
 
     settings.update({
-        'title': 'CIE 1960 UCS Chromaticity Diagram - {0}'.format(cmfs.title),
-        'x_label': 'CIE u',
-        'y_label': 'CIE v',
-        'grid': True,
+        'title':
+            'CIE 1960 UCS Chromaticity Diagram - {0}'.format(cmfs.strict_name),
+        'x_label':
+            'CIE u',
+        'y_label':
+            'CIE v',
+        'grid':
+            True,
         'bounding_box': (0, 1, 0, 1)
     })
     settings.update(kwargs)
 
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return render(**settings)
 
 
-def CIE_1976_UCS_chromaticity_diagram_colours_plot(
-        surface=1,
+def chromaticity_diagram_colours_CIE1976UCS(
         samples=4096,
         cmfs='CIE 1931 2 Degree Standard Observer',
-        **kwargs):
+        antialiasing=True):
     """
     Plots the *CIE 1976 UCS Chromaticity Diagram* colours.
 
     Parameters
     ----------
-    surface : numeric, optional
-        Generated markers surface.
     samples : numeric, optional
         Samples count on one axis.
     cmfs : unicode, optional
         Standard observer colour matching functions used for diagram bounds.
+    antialiasing : bool, optional
+        Whether to apply anti-aliasing to the image.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
-        Please refer to the documentation of the previously listed definitions.
+        {:func:`colour.plotting.render`},
+        Please refer to the documentation of the previously listed definition.
 
     Returns
     -------
@@ -473,53 +468,42 @@ def CIE_1976_UCS_chromaticity_diagram_colours_plot(
 
     Examples
     --------
-    >>> CIE_1976_UCS_chromaticity_diagram_colours_plot()  # doctest: +SKIP
+    >>> chromaticity_diagram_colours_CIE1976UCS()  # doctest: +SKIP
     """
 
-    settings = {'figure_size': (64, 64)}
-    settings.update(kwargs)
-
-    canvas(**settings)
-
     cmfs = get_cmfs(cmfs)
 
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
     triangulation = Delaunay(
         Luv_to_uv(XYZ_to_Luv(cmfs.values, illuminant), illuminant),
-        qhull_options='QJ Qf')
+        qhull_options='Qu QJ')
     xx, yy = np.meshgrid(
-        np.linspace(0, 1, samples), np.linspace(0, 1, samples))
+        np.linspace(0, 1, samples), np.linspace(1, 0, samples))
     xy = tstack((xx, yy))
-    xy = xy[triangulation.find_simplex(xy) > 0]
+    mask = (triangulation.find_simplex(xy) < 0).astype(DEFAULT_FLOAT_DTYPE)
+    if antialiasing:
+        kernel = np.array([
+            [0, 1, 0],
+            [1, 2, 1],
+            [0, 1, 0],
+        ]).astype(DEFAULT_FLOAT_DTYPE)
+        kernel /= np.sum(kernel)
+        mask = convolve(mask, kernel)
+
+    mask = 1 - mask[:, :, np.newaxis]
 
     XYZ = xy_to_XYZ(Luv_uv_to_xy(xy))
 
     RGB = normalise_maximum(XYZ_to_sRGB(XYZ, illuminant), axis=-1)
 
-    x_dot, y_dot = tsplit(xy)
-
-    pylab.scatter(x_dot, y_dot, color=RGB, s=surface)
-
-    settings.update({
-        'x_ticker': False,
-        'y_ticker': False,
-        'bounding_box': (0, 1, 0, 1)
-    })
-    settings.update(kwargs)
-
-    ax = matplotlib.pyplot.gca()
-    matplotlib.pyplot.setp(ax, frame_on=False)
-
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return np.dstack([RGB, mask])
 
 
-def CIE_1976_UCS_chromaticity_diagram_plot(
+def chromaticity_diagram_plot_CIE1976UCS(
         cmfs='CIE 1931 2 Degree Standard Observer',
         show_diagram_colours=True,
+        use_cached_diagram_colours=True,
         **kwargs):
     """
     Plots the *CIE 1976 UCS Chromaticity Diagram*.
@@ -530,12 +514,15 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
         Standard observer colour matching functions used for diagram bounds.
     show_diagram_colours : bool, optional
         Whether to display the chromaticity diagram background colours.
+    use_cached_diagram_colours : bool, optional
+        Whether to used the cached chromaticity diagram background colours
+        image.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
+        {:func:`colour.plotting.diagrams.\
+chromaticity_diagram_colours_CIE1976UCS`, :func:`colour.plotting.render`},
         Please refer to the documentation of the previously listed definitions.
 
     Returns
@@ -545,7 +532,7 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
 
     Examples
     --------
-    >>> CIE_1976_UCS_chromaticity_diagram_plot()  # doctest: +SKIP
+    >>> chromaticity_diagram_plot_CIE1976UCS()  # doctest: +SKIP
     """
 
     settings = {'figure_size': (DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_WIDTH)}
@@ -558,11 +545,18 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
     if show_diagram_colours:
-        image = matplotlib.image.imread(
-            os.path.join(PLOTTING_RESOURCES_DIRECTORY,
-                         'CIE_1976_UCS_Chromaticity_Diagram_{0}.png'.format(
-                             cmfs.name.replace(' ', '_'))))
-        pylab.imshow(image, interpolation=None, extent=(0, 1, 0, 1))
+        if use_cached_diagram_colours:
+            image = matplotlib.image.imread(
+                os.path.join(PLOTTING_RESOURCES_DIRECTORY,
+                             'CIE_1976_UCS_Chromaticity_Diagram_{0}.png'.
+                             format(cmfs.name.replace(' ', '_'))))
+        else:
+            image = chromaticity_diagram_colours_CIE1976UCS(
+                samples=kwargs.get('samples', 256),
+                cmfs=cmfs.name,
+                antialiasing=kwargs.get('antialiasing', True))
+
+        pylab.imshow(image, interpolation='bilinear', extent=(0, 1, 0, 1))
 
     labels = (420, 430, 440, 450, 460, 470, 480, 490, 500, 510, 520, 530, 540,
               550, 560, 570, 580, 590, 600, 610, 620, 630, 640, 680)
@@ -574,15 +568,15 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
 
     wavelengths_chromaticity_coordinates = dict(zip(wavelengths, uv))
 
-    pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=2)
+    pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=1)
     pylab.plot(
         (uv[-1][0], uv[0][0]), (uv[-1][1], uv[0][1]),
         color='black',
-        linewidth=2)
+        linewidth=1)
 
     for label in labels:
         u, v = wavelengths_chromaticity_coordinates[label]
-        pylab.plot(u, v, 'o', color='black', linewidth=2)
+        pylab.plot(u, v, 'o', color='black', linewidth=1)
 
         index = bisect.bisect(wavelengths, label)
         left = wavelengths[index - 1] if index >= 0 else wavelengths[index]
@@ -623,22 +617,27 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
     pylab.yticks(ticks)
 
     settings.update({
-        'title': 'CIE 1976 UCS Chromaticity Diagram - {0}'.format(cmfs.title),
-        'x_label': 'CIE u\'',
-        'y_label': 'CIE v\'',
-        'grid': True,
+        'title':
+            'CIE 1976 UCS Chromaticity Diagram - {0}'.format(cmfs.strict_name),
+        'x_label':
+            'CIE u\'',
+        'y_label':
+            'CIE v\'',
+        'grid':
+            True,
         'bounding_box': (0, 1, 0, 1)
     })
     settings.update(kwargs)
 
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return render(**settings)
 
 
-def spds_CIE_1931_chromaticity_diagram_plot(
-        spds, cmfs='CIE 1931 2 Degree Standard Observer', annotate=True,
+def spds_chromaticity_diagram_plot_CIE1931(
+        spds,
+        cmfs='CIE 1931 2 Degree Standard Observer',
+        annotate=True,
+        chromaticity_diagram_callable_CIE1931=(
+            chromaticity_diagram_plot_CIE1931),
         **kwargs):
     """
     Plots given spectral power distribution chromaticity coordinates into the
@@ -653,16 +652,21 @@ def spds_CIE_1931_chromaticity_diagram_plot(
     annotate : bool
         Should resulting chromaticity coordinates annotated with their
         respective spectral power distribution names.
+    chromaticity_diagram_callable_CIE1931 : callable, optional
+        Callable responsible for drawing the *CIE 1931 Chromaticity Diagram*.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
-        Please refer to the documentation of the previously listed definitions.
+        {:func:`colour.plotting.render`},
+        Please refer to the documentation of the previously listed definition.
     show_diagram_colours : bool, optional
-        {:func:`CIE_1931_chromaticity_diagram_plot`},
+        {:func:`colour.plotting.chromaticity_diagram_plot_CIE1931`},
         Whether to display the chromaticity diagram background colours.
+    use_cached_diagram_colours : bool, optional
+        {:func:`colour.plotting.chromaticity_diagram_plot_CIE1931`},
+        Whether to used the cached chromaticity diagram background colours
+        image.
 
     Returns
     -------
@@ -674,14 +678,14 @@ def spds_CIE_1931_chromaticity_diagram_plot(
     >>> from colour import ILLUMINANTS_RELATIVE_SPDS
     >>> A = ILLUMINANTS_RELATIVE_SPDS['A']
     >>> D65 = ILLUMINANTS_RELATIVE_SPDS['D65']
-    >>> spds_CIE_1931_chromaticity_diagram_plot([A, D65])  # doctest: +SKIP
+    >>> spds_chromaticity_diagram_plot_CIE1931([A, D65])  # doctest: +SKIP
     """
 
     settings = {}
     settings.update(kwargs)
-    settings.update({'standalone': False})
+    settings.update({'cmfs': cmfs, 'standalone': False})
 
-    CIE_1931_chromaticity_diagram_plot(cmfs=cmfs, **settings)
+    chromaticity_diagram_callable_CIE1931(**settings)
 
     for spd in spds:
         XYZ = spectral_to_XYZ(spd) / 100
@@ -707,14 +711,15 @@ def spds_CIE_1931_chromaticity_diagram_plot(
     })
     settings.update(kwargs)
 
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return render(**settings)
 
 
-def spds_CIE_1960_UCS_chromaticity_diagram_plot(
-        spds, cmfs='CIE 1931 2 Degree Standard Observer', annotate=True,
+def spds_chromaticity_diagram_plot_CIE1960UCS(
+        spds,
+        cmfs='CIE 1931 2 Degree Standard Observer',
+        annotate=True,
+        chromaticity_diagram_callable_CIE1960UCS=(
+            chromaticity_diagram_plot_CIE1960UCS),
         **kwargs):
     """
     Plots given spectral power distribution chromaticity coordinates into the
@@ -729,16 +734,22 @@ def spds_CIE_1960_UCS_chromaticity_diagram_plot(
     annotate : bool
         Should resulting chromaticity coordinates annotated with their
         respective spectral power distribution names.
+    chromaticity_diagram_callable_CIE1960UCS : callable, optional
+        Callable responsible for drawing the
+        *CIE 1960 UCS Chromaticity Diagram*.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
-        Please refer to the documentation of the previously listed definitions.
+        {:func:`colour.plotting.render`},
+        Please refer to the documentation of the previously listed definition.
     show_diagram_colours : bool, optional
-        {:func:`CIE_1960_UCS_chromaticity_diagram_plot`},
+        {:func:`colour.plotting.chromaticity_diagram_plot_CIE1960UCS`},
         Whether to display the chromaticity diagram background colours.
+    use_cached_diagram_colours : bool, optional
+        {:func:`colour.plotting.chromaticity_diagram_plot_CIE1960UCS`},
+        Whether to used the cached chromaticity diagram background colours
+        image.
 
     Returns
     -------
@@ -750,14 +761,14 @@ def spds_CIE_1960_UCS_chromaticity_diagram_plot(
     >>> from colour import ILLUMINANTS_RELATIVE_SPDS
     >>> A = ILLUMINANTS_RELATIVE_SPDS['A']
     >>> D65 = ILLUMINANTS_RELATIVE_SPDS['D65']
-    >>> spds_CIE_1960_UCS_chromaticity_diagram_plot([A, D65])  # doctest: +SKIP
+    >>> spds_chromaticity_diagram_plot_CIE1960UCS([A, D65])  # doctest: +SKIP
     """
 
     settings = {}
     settings.update(kwargs)
-    settings.update({'standalone': False})
+    settings.update({'cmfs': cmfs, 'standalone': False})
 
-    CIE_1960_UCS_chromaticity_diagram_plot(cmfs=cmfs, **settings)
+    chromaticity_diagram_callable_CIE1960UCS(**settings)
 
     for spd in spds:
         XYZ = spectral_to_XYZ(spd) / 100
@@ -783,14 +794,15 @@ def spds_CIE_1960_UCS_chromaticity_diagram_plot(
     })
     settings.update(kwargs)
 
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return render(**settings)
 
 
-def spds_CIE_1976_UCS_chromaticity_diagram_plot(
-        spds, cmfs='CIE 1931 2 Degree Standard Observer', annotate=True,
+def spds_chromaticity_diagram_plot_CIE1976UCS(
+        spds,
+        cmfs='CIE 1931 2 Degree Standard Observer',
+        annotate=True,
+        chromaticity_diagram_callable_CIE1976UCS=(
+            chromaticity_diagram_plot_CIE1976UCS),
         **kwargs):
     """
     Plots given spectral power distribution chromaticity coordinates into the
@@ -805,16 +817,22 @@ def spds_CIE_1976_UCS_chromaticity_diagram_plot(
     annotate : bool
         Should resulting chromaticity coordinates annotated with their
         respective spectral power distribution names.
+    chromaticity_diagram_callable_CIE1976UCS : callable, optional
+        Callable responsible for drawing the
+        *CIE 1976 UCS Chromaticity Diagram*.
 
     Other Parameters
     ----------------
     \**kwargs : dict, optional
-        {:func:`boundaries`, :func:`canvas`, :func:`decorate`,
-        :func:`display`},
-        Please refer to the documentation of the previously listed definitions.
+        {:func:`colour.plotting.render`},
+        Please refer to the documentation of the previously listed definition.
     show_diagram_colours : bool, optional
-        {:func:`CIE_1976_UCS_chromaticity_diagram_plot`},
+        {:func:`colour.plotting.chromaticity_diagram_plot_CIE1976UCS`},
         Whether to display the chromaticity diagram background colours.
+    use_cached_diagram_colours : bool, optional
+        {:func:`colour.plotting.chromaticity_diagram_plot_CIE1976UCS`},
+        Whether to used the cached chromaticity diagram background colours
+        image.
 
     Returns
     -------
@@ -826,14 +844,14 @@ def spds_CIE_1976_UCS_chromaticity_diagram_plot(
     >>> from colour import ILLUMINANTS_RELATIVE_SPDS
     >>> A = ILLUMINANTS_RELATIVE_SPDS['A']
     >>> D65 = ILLUMINANTS_RELATIVE_SPDS['D65']
-    >>> spds_CIE_1976_UCS_chromaticity_diagram_plot([A, D65])  # doctest: +SKIP
+    >>> spds_chromaticity_diagram_plot_CIE1976UCS([A, D65])  # doctest: +SKIP
     """
 
     settings = {}
     settings.update(kwargs)
-    settings.update({'standalone': False})
+    settings.update({'cmfs': cmfs, 'standalone': False})
 
-    CIE_1976_UCS_chromaticity_diagram_plot(cmfs=cmfs, **settings)
+    chromaticity_diagram_callable_CIE1976UCS(**settings)
 
     for spd in spds:
         XYZ = spectral_to_XYZ(spd) / 100
@@ -859,7 +877,4 @@ def spds_CIE_1976_UCS_chromaticity_diagram_plot(
     })
     settings.update(kwargs)
 
-    boundaries(**settings)
-    decorate(**settings)
-
-    return display(**settings)
+    return render(**settings)
